==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/analysis/ActiveUseValueSwitch.h <==
// public class org.dellroad.jc.cgen.analysis.ActiveUseValueSwitch

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e07e54011ac7553c org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch
// @dep_class 4ecfaa3a7ae14cd1 soot_grimp_AbstractGrimpValueSwitch
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_grimp_AbstractGrimpValueSwitch

#include "soot/grimp/AbstractGrimpValueSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch_H_
#define _JC_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_grimp_NewInvokeExpr$object;
struct _jc_soot_jimple_InstanceFieldRef$object;
struct _jc_soot_jimple_NewExpr$object;
struct _jc_soot_jimple_SpecialInvokeExpr$object;
struct _jc_soot_jimple_StaticFieldRef$object;
struct _jc_soot_jimple_StaticInvokeExpr$object;
struct _jc_soot_jimple_VirtualInvokeExpr$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vmethods	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtable	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseInstanceFieldRef$edd1ca12bae45903(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseNewExpr$a19e03ca0d8a8f14(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseNewInvokeExpr$d2257fbd4cc811f6(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseSpecialInvokeExpr$0a544b1305ce4e29(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseStaticFieldRef$80e41c7d355e896d(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_soot_jimple_StaticFieldRef$object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseStaticInvokeExpr$21a5bc0298057d64(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseVirtualInvokeExpr$7ab57606cc578e03(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseInstanceFieldRef$edd1ca12bae45903;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseNewExpr$a19e03ca0d8a8f14;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseNewInvokeExpr$d2257fbd4cc811f6;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseSpecialInvokeExpr$0a544b1305ce4e29;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseStaticFieldRef$80e41c7d355e896d;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseStaticInvokeExpr$21a5bc0298057d64;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseVirtualInvokeExpr$7ab57606cc578e03;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vmethods {
	void	(*caseInstanceFieldRef$edd1ca12bae45903)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
	void	(*caseNewExpr$a19e03ca0d8a8f14)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
	void	(*caseNewInvokeExpr$d2257fbd4cc811f6)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
	void	(*caseSpecialInvokeExpr$0a544b1305ce4e29)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
	void	(*caseStaticFieldRef$80e41c7d355e896d)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_soot_jimple_StaticFieldRef$object *);
	void	(*caseStaticInvokeExpr$21a5bc0298057d64)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
	void	(*caseVirtualInvokeExpr$7ab57606cc578e03)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_grimp_AbstractGrimpValueSwitch$vmethods	soot_grimp_AbstractGrimpValueSwitch;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vmethods	org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$refs {
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_refs	org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch;
    _jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs	soot_grimp_AbstractGrimpValueSwitch;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs	soot_grimp_AbstractGrimpValueSwitch;
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_nonrefs	org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object {
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/analysis/ActiveUseValueSwitch.h <==
// public class org.dellroad.jc.cgen.analysis.ActiveUseValueSwitch

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e07e54011ac7553c org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch
// @dep_class 4ecfaa3a7ae14cd1 soot_grimp_AbstractGrimpValueSwitch
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_grimp_AbstractGrimpValueSwitch

#include "soot/grimp/AbstractGrimpValueSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch_H_
#define _JC_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_grimp_NewInvokeExpr$object;
struct _jc_soot_jimple_InstanceFieldRef$object;
struct _jc_soot_jimple_NewExpr$object;
struct _jc_soot_jimple_SpecialInvokeExpr$object;
struct _jc_soot_jimple_StaticFieldRef$object;
struct _jc_soot_jimple_StaticInvokeExpr$object;
struct _jc_soot_jimple_VirtualInvokeExpr$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vmethods	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtable	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseInstanceFieldRef$edd1ca12bae45903(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseNewExpr$a19e03ca0d8a8f14(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseNewInvokeExpr$d2257fbd4cc811f6(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseSpecialInvokeExpr$0a544b1305ce4e29(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseStaticFieldRef$80e41c7d355e896d(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_soot_jimple_StaticFieldRef$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseStaticInvokeExpr$21a5bc0298057d64(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method$caseVirtualInvokeExpr$7ab57606cc578e03(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseInstanceFieldRef$edd1ca12bae45903;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseNewExpr$a19e03ca0d8a8f14;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseNewInvokeExpr$d2257fbd4cc811f6;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseSpecialInvokeExpr$0a544b1305ce4e29;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseStaticFieldRef$80e41c7d355e896d;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseStaticInvokeExpr$21a5bc0298057d64;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$method_info$caseVirtualInvokeExpr$7ab57606cc578e03;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vmethods {
	void	(*caseInstanceFieldRef$edd1ca12bae45903)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseNewExpr$a19e03ca0d8a8f14)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseNewInvokeExpr$d2257fbd4cc811f6)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseSpecialInvokeExpr$0a544b1305ce4e29)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseStaticFieldRef$80e41c7d355e896d)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_soot_jimple_StaticFieldRef$object *) _JC_JCNI_ATTR;
	void	(*caseStaticInvokeExpr$21a5bc0298057d64)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseVirtualInvokeExpr$7ab57606cc578e03)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_grimp_AbstractGrimpValueSwitch$vmethods	soot_grimp_AbstractGrimpValueSwitch;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vmethods	org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$refs {
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_refs	org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch;
    _jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs	soot_grimp_AbstractGrimpValueSwitch;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs	soot_grimp_AbstractGrimpValueSwitch;
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$sub_nonrefs	org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$object {
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$vtype _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ActiveUseValueSwitch_H_ */
